@@ -2,7 +2,7 @@ use crate::{
     command::{args, PROGRESS_CHARS},
     console_ext::style,
     ffprobe,
-    process::FfmpegProgress,
+    process::FfmpegOut,
     svtav1::{self},
     temporary::{self, TempKind},
 };
@@ -42,10 +42,12 @@ pub async fn run(
     Args {
         svt,
         crf,
-        encode: args::EncodeToOutput {
-            output,
-            audio_codec,
-        },
+        encode:
+            args::EncodeToOutput {
+                output,
+                audio_codec,
+                downmix_to_stereo,
+            },
     }: Args,
     bar: &ProgressBar,
 ) -> anyhow::Result<()> {
@@ -66,14 +68,31 @@ pub async fn run(
         bar.set_length(d.as_secs());
     }
 
-    let mut enc = svtav1::encode(svt_args, &output, has_audio, audio_codec.as_deref())?;
+    // only downmix if achannels > 3
+    let stereo_downmix = downmix_to_stereo && probe.max_audio_channels.map_or(false, |c| c > 3);
+    let audio_codec = audio_codec.as_deref();
+    if stereo_downmix && audio_codec == Some("copy") {
+        anyhow::bail!("--stereo-downmix cannot be used with --acodec copy");
+    }
+
+    let mut enc = svtav1::encode(svt_args, &output, has_audio, audio_codec, stereo_downmix)?;
+    let mut stream_sizes = None;
     while let Some(progress) = enc.next().await {
-        let FfmpegProgress { fps, time, .. } = progress?;
-        if fps > 0.0 {
-            bar.set_message(format!("{fps} fps, "));
-        }
-        if probe.duration.is_ok() {
-            bar.set_position(time.as_secs());
+        match progress? {
+            FfmpegOut::Progress { fps, time, .. } => {
+                if fps > 0.0 {
+                    bar.set_message(format!("{fps} fps, "));
+                }
+                if probe.duration.is_ok() {
+                    bar.set_position(time.as_secs());
+                }
+            }
+            FfmpegOut::StreamSizes {
+                video,
+                audio,
+                subtitle,
+                other,
+            } => stream_sizes = Some((video, audio, subtitle, other)),
         }
     }
     bar.finish();
@@ -86,18 +105,39 @@ pub async fn run(
     let output_percent = 100.0 * output_size as f64 / fs::metadata(&svt.input).await?.len() as f64;
     let output_size = style(HumanBytes(output_size)).dim().bold();
     let output_percent = style!("{}%", output_percent.round()).dim().bold();
-    eprintln!(
-        "{} {output_size} {}{output_percent}{}",
+    eprint!(
+        "{} {output_size} {}{output_percent}",
         style("Encoded").dim(),
         style("(").dim(),
-        style(")").dim(),
     );
+    if let Some((video, audio, subtitle, other)) = stream_sizes {
+        if audio > 0 || subtitle > 0 || other > 0 {
+            for (label, size) in [
+                ("video:", video),
+                ("audio:", audio),
+                ("subs:", subtitle),
+                ("other:", other),
+            ] {
+                if size > 0 {
+                    let size = style(HumanBytes(size)).dim();
+                    eprint!("{} {}{size}", style(",").dim(), style(label).dim(),);
+                }
+            }
+        }
+    }
+    eprintln!("{}", style(")").dim());
+
     Ok(())
 }
 
 /// * input: vid.ext -> output: vid.av1.ext
 pub fn default_output_from(input: &Path) -> PathBuf {
-    match input.extension().and_then(|e| e.to_str()) {
+    match input
+        .extension()
+        .and_then(|e| e.to_str())
+        // don't use extensions that won't work
+        .filter(|e| *e != "avi" && *e != "y4m" && *e != "ivf")
+    {
         Some(ext) => input.with_extension(format!("av1.{ext}")),
         _ => input.with_extension("av1.mp4"),
     }
