@@ -4,7 +4,7 @@ use crate::{
         PROGRESS_CHARS,
     },
     ffprobe,
-    process::FfmpegProgress,
+    process::FfmpegOut,
     vmaf,
     vmaf::VmafOut,
 };
@@ -49,7 +49,10 @@ pub async fn vmaf(
     bar.enable_steady_tick(100);
     bar.set_message("vmaf running, ");
 
-    let duration = ffprobe::probe(&reference).duration;
+    let dprobe = ffprobe::probe(&distorted);
+    let duration = dprobe
+        .duration
+        .or_else(|_| ffprobe::probe(&reference).duration);
     if let Ok(d) = duration {
         bar.set_length(d.as_secs());
     }
@@ -58,7 +61,7 @@ pub async fn vmaf(
         &reference,
         reference_vfilter.as_deref(),
         &distorted,
-        &vmaf.ffmpeg_lavfi(),
+        &vmaf.ffmpeg_lavfi(dprobe.resolution),
         PixelFormat::Yuv420p10le,
     )?;
     let mut vmaf_score = -1.0;
@@ -68,7 +71,7 @@ pub async fn vmaf(
                 vmaf_score = score;
                 break;
             }
-            VmafOut::Progress(FfmpegProgress { time, fps, .. }) => {
+            VmafOut::Progress(FfmpegOut::Progress { time, fps, .. }) => {
                 if fps > 0.0 {
                     bar.set_message(format!("vmaf {fps} fps, "));
                 }
@@ -76,6 +79,7 @@ pub async fn vmaf(
                     bar.set_position(time.as_secs());
                 }
             }
+            VmafOut::Progress(_) => {}
             VmafOut::Err(e) => return Err(e),
         }
     }
