@@ -11,7 +11,7 @@ mod yuv;
 use anyhow::anyhow;
 use clap::Parser;
 use futures::FutureExt;
-use std::time::Duration;
+use std::{io, time::Duration};
 use tokio::signal;
 
 const SAMPLE_SIZE_S: u64 = 20;
@@ -37,15 +37,14 @@ enum Action {
 #[tokio::main(flavor = "current_thread")]
 async fn main() -> anyhow::Result<()> {
     let Args { action } = Args::parse();
-    let mut keep = false;
+
+    action.ensure_temp_dir_exists().await?;
+    let keep = action.keep_temp_files();
 
     let local = tokio::task::LocalSet::new();
 
     let command = local.run_until(match action {
-        Action::SampleEncode(args) => {
-            keep = args.keep;
-            command::sample_encode(args).boxed_local()
-        }
+        Action::SampleEncode(args) => command::sample_encode(args).boxed_local(),
         Action::Vmaf(args) => command::vmaf(args).boxed_local(),
         Action::Encode(args) => command::encode(args).boxed_local(),
         Action::CrfSearch(args) => command::crf_search(args).boxed_local(),
@@ -58,9 +57,29 @@ async fn main() -> anyhow::Result<()> {
         _ = signal::ctrl_c() => Err(anyhow!("ctrl_c")),
     };
 
-    if !keep {
-        temporary::clean().await;
-    }
+    temporary::clean(keep).await;
 
     out
 }
+
+impl Action {
+    fn keep_temp_files(&self) -> bool {
+        match self {
+            Self::SampleEncode(args) => args.keep,
+            _ => false,
+        }
+    }
+
+    async fn ensure_temp_dir_exists(&self) -> io::Result<()> {
+        let temp_dir = match self {
+            Self::SampleEncode(args) => &args.sample.temp_dir,
+            Self::CrfSearch(args) => &args.sample.temp_dir,
+            Self::AutoEncode(args) => &args.search.sample.temp_dir,
+            _ => &None,
+        };
+        if let Some(dir) = temp_dir {
+            tokio::fs::create_dir_all(dir).await?;
+        }
+        Ok(())
+    }
+}
