@@ -1,7 +1,8 @@
 //! ffmpeg logic
 use crate::{
     process::{ensure_success, CommandExt},
-    temporary, SAMPLE_SIZE_S,
+    temporary::{self, TempKind},
+    SAMPLE_SIZE_S,
 };
 use anyhow::Context;
 use std::{
@@ -13,17 +14,27 @@ use tokio::process::Command;
 /// Create a 20s sample from `sample_start`.
 ///
 /// Fast as this uses `-c:v copy`.
-pub async fn copy(input: &Path, sample_start: Duration) -> anyhow::Result<PathBuf> {
+pub async fn copy(
+    input: &Path,
+    sample_start: Duration,
+    temp_dir: Option<PathBuf>,
+) -> anyhow::Result<PathBuf> {
     let ext = input
         .extension()
         .and_then(|e| e.to_str())
         .context("input has no extension")?;
-    let dest = input.with_extension(format!(
+    let mut dest = input.with_extension(format!(
         "sample{}+{SAMPLE_SIZE_S}.{ext}",
         sample_start.as_secs()
     ));
-
-    temporary::add(&dest);
+    if let (Some(mut temp), Some(name)) = (temp_dir, dest.file_name()) {
+        temp.push(name);
+        dest = temp;
+    }
+    if dest.exists() {
+        return Ok(dest);
+    }
+    temporary::add(&dest, TempKind::Keepable);
 
     let out = Command::new("ffmpeg")
         .arg("-y")
