@@ -1,7 +1,7 @@
 //! svt-av1 logic
 use crate::{
     command::args::PixelFormat,
-    process::{exit_ok_option, CommandExt, FfmpegProgress},
+    process::{exit_ok_option, CommandExt, FfmpegOut},
     temporary::{self, TempKind},
     yuv,
 };
@@ -42,7 +42,7 @@ pub fn encode_ivf(
         args,
     }: SvtArgs,
     temp_dir: Option<PathBuf>,
-) -> anyhow::Result<(PathBuf, impl Stream<Item = anyhow::Result<FfmpegProgress>>)> {
+) -> anyhow::Result<(PathBuf, impl Stream<Item = anyhow::Result<FfmpegOut>>)> {
     let mut dest = input.with_extension(format!("crf{crf}.p{preset}.ivf"));
     if let (Some(mut temp), Some(name)) = (temp_dir, dest.file_name()) {
         temp.push(name);
@@ -90,11 +90,13 @@ pub fn encode(
     output: &Path,
     has_audio: bool,
     audio_codec: Option<&str>,
-) -> anyhow::Result<impl Stream<Item = anyhow::Result<FfmpegProgress>>> {
+    downmix_to_stereo: bool,
+) -> anyhow::Result<impl Stream<Item = anyhow::Result<FfmpegOut>>> {
     let output_mp4 = output.extension().and_then(|e| e.to_str()) == Some("mp4");
 
     // use `-c:a copy` if the extensions are the same, otherwise re-encode with opus
     let audio_codec = audio_codec.unwrap_or_else(|| match input.extension() {
+        _ if downmix_to_stereo => "libopus",
         ext if ext.is_some() && ext == output.extension() => "copy",
         _ if !has_audio => "copy",
         _ => "libopus",
@@ -132,11 +134,14 @@ pub fn encode(
         .arg("-y")
         .arg2("-i", "-")
         .arg2("-i", input)
+        // use av1 video
         .arg2("-map", "0:v")
-        .arg2("-map", "1:a?")
-        .arg2("-map", "1:s?")
+        // map everything but video from input
+        .arg2("-map", "1")
+        .arg2("-map", "-1:v")
         .arg2("-c:s", "copy")
         .arg2("-c:a", audio_codec)
+        .arg2_if(downmix_to_stereo, "-ac", 2)
         .arg2("-c:v", "copy")
         .arg2_if(audio_codec == "libopus", "-b:a", "128k")
         .arg2_if(output_mp4, "-movflags", "+faststart")
@@ -144,7 +149,7 @@ pub fn encode(
         .spawn()
         .context("ffmpeg to-output")?;
 
-    let to_mp4 = FfmpegProgress::stream(to_output, "ffmpeg to-output");
+    let to_mp4 = FfmpegOut::stream(to_output, "ffmpeg to-output");
 
     Ok(yuv_pipe.merge(svt).merge(to_mp4))
 }
