@@ -1,7 +1,7 @@
 //! vmaf logic
 use crate::{
     command::args::PixelFormat,
-    process::{exit_ok, CommandExt, FfmpegProgress},
+    process::{exit_ok, CommandExt, FfmpegOut},
     yuv,
 };
 use anyhow::Context;
@@ -16,7 +16,7 @@ pub fn run(
     reference: &Path,
     reference_vfilter: Option<&str>,
     distorted: &Path,
-    lavfi: &str,
+    filter_complex: &str,
     pix_fmt: PixelFormat,
 ) -> anyhow::Result<impl Stream<Item = VmafOut>> {
     let (yuv_out, yuv_pipe) = yuv::pipe(reference, pix_fmt, reference_vfilter)?;
@@ -35,7 +35,7 @@ pub fn run(
         .kill_on_drop(true)
         .arg2("-i", distorted)
         .arg2("-i", "-")
-        .arg2("-lavfi", lavfi)
+        .arg2("-filter_complex", filter_complex)
         .arg2("-f", "null")
         .arg("-")
         .stdin(yuv_out)
@@ -52,7 +52,7 @@ pub fn run(
 
 #[derive(Debug)]
 pub enum VmafOut {
-    Progress(FfmpegProgress),
+    Progress(FfmpegOut),
     Done(f32),
     Err(anyhow::Error),
 }
@@ -72,7 +72,7 @@ impl VmafOut {
                 out[idx + "VMAF score: ".len()..].trim().parse().ok()?,
             ));
         }
-        if let Some(progress) = FfmpegProgress::try_parse(&out) {
+        if let Some(progress) = FfmpegOut::try_parse(&out) {
             return Some(Self::Progress(progress));
         }
         None
